@@ -3,13 +3,15 @@ from .fullname_json import FullnameJson
 from .values.text_val import TextVal
 from .values.null import NULL
 from .values.holder import Holder
+from .values.true import TRUE
+from .values.false import FALSE
 
 
-class Field(FullnameJson, TextVal, NULL, Holder):
+class Field(FullnameJson, TextVal, NULL, Holder, TRUE, FALSE):
     reserved = {**Base.reserved, **TextVal.reserved,
-                **FullnameJson.reserved, **NULL.reserved, **Holder.reserved, }
+                **FullnameJson.reserved, **NULL.reserved, **Holder.reserved, **TRUE.reserved, **FALSE.reserved}
     tokens = Base.tokens + TextVal.tokens + \
-        FullnameJson.tokens + NULL.tokens + Holder.tokens
+        FullnameJson.tokens + NULL.tokens + Holder.tokens + TRUE.tokens + FALSE.tokens
 
     # Tokens
 
@@ -19,7 +21,9 @@ class Field(FullnameJson, TextVal, NULL, Holder):
     @_rule('''field : STAR
                     | NUMBER
                     | TEXTVAL
-                    | NULL''')
+                    | NULL
+                    | TRUE
+                    | FALSE''')
     def p_field_items(self, p):
         p[0] = self.provider.new_record(p[1])
 
